==> seedsui-react-5.8.7.tgz: package/lib/TreePicker/Tree/utils/filterValue.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
// 过滤值
function filterValue(value, type) {
  if (Array.isArray(value) === false || !value.length) return value;
  // 只显示父级
  if (type === 'parent') {
    var _iterator = _createForOfIteratorHelper(value),
      _step;
    try {
      var _loop = function _loop() {
        var item = _step.value;
        if (item.halfChecked || !item.id || item.disabled) return "continue";
        var descendants = value.getFlattenTreeDescendants(item.id);
        var descendantIds = descendants.map(function (descendant) {
          return descendant.id;
        });
        // eslint-disable-next-line
        value = value.filter(function (n) {
          if (descendantIds.includes(n.id)) {
            return false;
          }
          return true;
        });
      };
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _ret = _loop();
        if (_ret === "continue") continue;
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  // 只显示子级
  else if (type === 'leaf') {
    var _iterator2 = _createForOfIteratorHelper(value),
      _step2;
    try {
      var _loop2 = function _loop2() {
        var item = _step2.value;
        if (item.halfChecked || !item.id || item.disabled) return "continue";
        var predecessors = value.getFlattenTreePredecessor(item.id);
        var predecessorIds = predecessors.map(function (predecessor) {
          return predecessor.id;
        });
        // eslint-disable-next-line
        value = value.filter(function (n) {
          if (predecessorIds.includes(n.id)) {
            return false;
          }
          return true;
        });
      };
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var _ret2 = _loop2();
        if (_ret2 === "continue") continue;
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
  }
  return value;
}
export default filterValue;

==> seedsui-react-5.8.44.tgz: package/lib/TreePicker/Tree/utils/filterValue.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
// 过滤值
function filterValue(value, type) {
  if (Array.isArray(value) === false || !value.length) return value;
  // 只显示父级
  if (type === 'parent') {
    var _iterator = _createForOfIteratorHelper(value),
      _step;
    try {
      var _loop = function _loop() {
        var item = _step.value;
        if (item.halfChecked || !item.id || item.disabled) return 1; // continue
        var descendants = value.getFlattenTreeDescendants(item.id);
        var descendantIds = descendants.map(function (descendant) {
          return descendant.id;
        });
        // eslint-disable-next-line
        value = value.filter(function (n) {
          if (descendantIds.includes(n.id)) {
            return false;
          }
          return true;
        });
      };
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        if (_loop()) continue;
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  // 只显示子级
  else if (type === 'leaf') {
    var _iterator2 = _createForOfIteratorHelper(value),
      _step2;
    try {
      var _loop2 = function _loop2() {
        var item = _step2.value;
        if (item.halfChecked || !item.id || item.disabled) return 1; // continue
        var predecessors = value.getFlattenTreePredecessor(item.id);
        var predecessorIds = predecessors.map(function (predecessor) {
          return predecessor.id;
        });
        // eslint-disable-next-line
        value = value.filter(function (n) {
          if (predecessorIds.includes(n.id)) {
            return false;
          }
          return true;
        });
      };
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        if (_loop2()) continue;
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
  }
  return value;
}
export default filterValue;
